@@ -1,6 +1,6 @@
 """
 Start building tests for the concept of a tiddler collection,
-which is likely a subclass of a generic colleciton.
+which is likely a subclass of a generic collection.
 
 A collection provides:
 
@@ -14,68 +14,73 @@ from tiddlyweb.model.collections import Collection, Tiddlers
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.bag import Bag
 
-from tiddlywebplugins.utils import get_store
-
-from fixtures import reset_textstore
+from .fixtures import reset_textstore, get_store
 
 
 def setup_module(module):
     reset_textstore()
     module.store = get_store(config)
 
+
 def test_create_collection():
     collection = Collection()
-
     assert isinstance(collection, Collection)
 
-def test_collection_title():
-    collection = Collection('barney')
 
-    assert collection.title == 'barney'
+def test_collection_title():
+    collection = Collection(u'barney')
+    assert collection.title == u'barney'
+
 
 def test_add_thing():
     collection = Collection()
-    collection.add('monkey')
+    collection.add(u'monkey')
+    assert u'monkey' in collection
 
-    assert 'monkey' in collection
 
 def test_hash_things():
     collection = Collection()
 
-    collection.add('monkey')
-    assert 'monkey' in collection
+    collection.add(u'monkey')
+    assert u'monkey' in collection
+
     mdigest = collection.hexdigest()
-    assert mdigest 
+    assert mdigest
+
+    collection.add(u'cow')
+    assert u'cow' in collection
 
-    collection.add('cow')
-    assert 'cow' in collection
     cdigest = collection.hexdigest()
-    assert cdigest 
-
+    assert cdigest
     assert mdigest != cdigest
 
+
 def test_get_things():
     collection = Collection()
-    collection.add('monkey')
-    collection.add('cow')
+    collection.add(u'monkey')
+    collection.add(u'cow')
     all = list(collection)
-    assert all == ['monkey', 'cow']
+    assert all == [u'monkey', u'cow']
+
 
 def test_tiddler_collection():
     tiddlers = Tiddlers()
     n = 4
-    for title in ['how', 'now', 'cow']:
+    for title in [u'how', u'now', u'cow']:
         n = n - 1
         tiddler = Tiddler(title, 'bag')
-        tiddler.modified = n 
+        tiddler.modified = n
         tiddlers.add(tiddler)
-    digest = tiddlers.hexdigest()
     modified = tiddlers.modified
-    assert ['how', 'now', 'cow'] == list(tiddler.title for tiddler in tiddlers)
+    assert [u'how', u'now', u'cow'] == list(
+            tiddler.title for tiddler in tiddlers)
     assert modified == '30000000000000'
 
+
 def test_tiddler_racing():
-    def race_tiddlers(bag_name, count=2, intitles=['x', 'z'], outtitles=['y']):
+
+    def race_tiddlers(bag_name, count=2, intitles=['x', 'z'],
+            outtitles=['y']):
         bag = Bag(bag_name)
         store.put(bag)
         tiddlers = Tiddlers(store=store)
@@ -91,9 +96,10 @@ def test_tiddler_racing():
         tids = list(tiddlers)
         assert len(tids) == count
         for title in intitles:
-            assert title in [tiddler.title for tiddler in tids]
+            assert title in [tid.title for tid in tids]
         for title in outtitles:
-            assert title not in [tiddler.title for tiddler in tids]
+            assert title not in [tid.title for tid in tids]
+
     stored_config = config.get('collections.use_memory')
     config['collections.use_memory'] = False
     race_tiddlers('foo')
@@ -101,6 +107,8 @@ def test_tiddler_racing():
     race_tiddlers('bar', count=3, intitles=['x', 'y', 'z'], outtitles=[])
     store.delete(Bag('foo'))
     store.delete(Bag('bar'))
+    config['collections.use_memory'] = stored_config
+
 
 def test_tiddlers_container():
     tiddlers = Tiddlers()
