@@ -1,16 +1,18 @@
 
-
-from fixtures import reset_textstore, muchdata, _teststore
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
 
+from .fixtures import reset_textstore, muchdata, _teststore
+
 name = u'boom\u00BB\u00BBboom'
 
+
 def setup_module(module):
     reset_textstore()
     module.store = _teststore()
     muchdata(store)
 
+
 def test_simple_search():
     tiddlers = list(store.search('i am tiddler 0'))
 
@@ -18,8 +20,8 @@ def test_simple_search():
     assert type(tiddlers[0]) == Tiddler
     assert tiddlers[0].text is u''
 
-def test_unicode_search():
 
+def test_unicode_search():
     bag = Bag(name)
     store.put(bag)
 
