@@ -5,12 +5,12 @@ to the available :py:class:`challengers
 challenger, redirect to it.
 """
 
-import urllib
-
 from httpexceptor import HTTP302, HTTP404
 
 from tiddlyweb.web.util import server_base_url, get_route_value, html_frame
 
+from tiddlyweb.fixups import quote
+
 
 def base(environ, start_response):
     """
@@ -67,7 +67,7 @@ def _challenger_url(environ, system):
     default_redirect = '%s/' % environ['tiddlyweb.config']['server_prefix']
     redirect = (environ['tiddlyweb.query'].get('tiddlyweb_redirect',
             [default_redirect])[0])
-    redirect = '?tiddlyweb_redirect=%s' % urllib.quote(
+    redirect = '?tiddlyweb_redirect=%s' % quote(
             redirect.encode('utf-8'), safe='')
     return '%s/challenge/%s%s' % (server_base_url(environ), system, redirect)
 
@@ -84,7 +84,7 @@ def _determine_challenger(environ, challenger_name=None):
         raise HTTP404('Challenger Not Found')
     try:
         return _get_challenger_module(challenger_name)
-    except ImportError, exc:
+    except ImportError as exc:
         raise HTTP404('Unable to import challenger %s: %s' %
                 (challenger_name, exc))
 
