@@ -3,7 +3,7 @@ An :py:class:`extractor <tiddlyweb.web.extractors.ExtractorInterface>`
 that looks at a cookie named ``tiddlyweb_user``.
 """
 
-import Cookie
+
 import logging
 
 from httpexceptor import HTTP400
@@ -11,6 +11,7 @@ from httpexceptor import HTTP400
 from tiddlyweb.web.extractors import ExtractorInterface
 from tiddlyweb.util import sha
 
+from tiddlyweb.fixups import SimpleCookie, CookieError
 
 LOGGER = logging.getLogger(__name__)
 
@@ -32,17 +33,16 @@ class Extractor(ExtractorInterface):
             user_cookie = environ['HTTP_COOKIE']
             LOGGER.debug('simple_cookie looking at cookie string: %s',
                     user_cookie)
-            cookie = Cookie.SimpleCookie()
-            cookie.load(user_cookie)
+            cookie = SimpleCookie()
+            cookie.load(str(user_cookie))
             cookie_value = cookie['tiddlyweb_user'].value
             secret = environ['tiddlyweb.config']['secret']
             usersign, cookie_secret = cookie_value.rsplit(':', 1)
 
             if cookie_secret == sha('%s%s' % (usersign, secret)).hexdigest():
-                usersign = usersign.decode('utf-8')
                 user = self.load_user(environ, usersign)
                 return {"name": user.usersign, "roles": user.list_roles()}
-        except Cookie.CookieError, exc:
+        except CookieError as exc:
             raise HTTP400('malformed cookie: %s' % exc)
         except (KeyError, ValueError):
             pass
